@@ -186,6 +186,8 @@ sub init_default_attributes
 	# f_map is deprecated (but might return)
 	$dbh->{f_dir}      = Cwd::abs_path (File::Spec->curdir ());
 
+	push @{$dbh->{sql_init_order}{90}}, "f_meta";
+
 	if(0) { # XXX remove block
 	# complete derived attributes, if required
 	(my $drv_class = $dbh->{ImplementorClass}) =~ s/::db$//;
@@ -403,7 +405,14 @@ use warnings;
 
 # We may have a working flock () built-in but that doesn't mean that locking
 # will work on NFS (flock () may hang hard)
-my $locking = eval { flock STDOUT, 0; 1 };
+my $locking = eval {
+    my $fh;
+    my $nulldevice = File::Spec->devnull();
+    open( $fh, ">", $nulldevice ) or die "Can't open $nulldevice: $!";
+    flock $fh, 0;
+    close $fh;
+    1
+    };
 
 use Carp;
 
