@@ -8,9 +8,9 @@
     require DBI::Gofer::Response;
     require Carp;
 
-    our $VERSION = sprintf("0.%06d", q$Revision: 10087 $ =~ /(\d+)/o);
+    our $VERSION = sprintf("0.%06d", q$Revision: 15372 $ =~ /(\d+)/o);
 
-#   $Id: Gofer.pm 10087 2007-10-16 12:42:37Z timbo $
+#   $Id: Gofer.pm 15372 2012-08-29 07:09:55Z REHSACK $
 #
 #   Copyright (c) 2007, Tim Bunce, Ireland
 #
@@ -29,6 +29,7 @@
         FetchHashKeyName
         HandleError HandleSetErr
         InactiveDestroy
+        AutoInactiveDestroy
         PrintError PrintWarn
         Profile
         RaiseError
@@ -46,7 +47,7 @@
         dbi_connect_method
     );
 
-    our $drh = undef;    # holds driver handle once initialised
+    our $drh = undef;    # holds driver handle once initialized
     our $methods_already_installed;
 
     sub driver{
@@ -91,11 +92,17 @@
 
 
     sub set_err_from_response { # set error/warn/info and propagate warnings
-        my ($h, $response) = @_;
+        my $h = shift;
+        my $response = shift;
         if (my $warnings = $response->warnings) {
             warn $_ for @$warnings;
         }
-        return $h->set_err($response->err, $response->errstr, $response->state);
+        my ($err, $errstr, $state) = $response->err_errstr_state;
+        # Only set_err() if there's an error else leave the current values
+        # (The current values will normally be set undef by the DBI dispatcher
+        # except for methods marked KEEPERR such as ping.)
+        $h->set_err($err, $errstr, $state) if defined $err;
+        return undef;
     }
 
 
@@ -301,7 +308,7 @@
 
         if (my $dbh_attributes = $response->dbh_attributes) {
 
-            # XXX installed_methods piggbacks on dbh_attributes for now
+            # XXX installed_methods piggybacks on dbh_attributes for now
             if (my $installed_methods = delete $dbh_attributes->{dbi_installed_methods}) {
                 DBD::Gofer::install_methods_proxy($installed_methods)
                     if $dbh->{go_request_count}==1;
@@ -326,6 +333,10 @@
             # and return that new sth as if it came from original request
             $rv = [ $sth ];
         }
+        elsif (!$rv) { # should only occur for major transport-level error
+            #carp("no rv in response { @{[ %$response ]} }");
+            $rv = [ ];
+        }
 
         DBD::Gofer::set_err_from_response($dbh, $response);
 
@@ -578,7 +589,7 @@
             # but only works properly for params 1..9
             # (reverse because of the unshift)
             my @params = reverse sort keys %$ParamValues;
-            if (@params > 9 && $sth->{Database}{go_dsn} =~ /dbi:Sybase/) {
+            if (@params > 9 && ($sth->{Database}{go_dsn}||'') =~ /dbi:Sybase/) {
                 # if more than 9 then we need to do a proper numeric sort
                 # also warn to alert user of this issue
                 warn "Sybase param binding order hack in use";
@@ -630,19 +641,19 @@
             $dbh->{go_dbh_attributes_fetched} = $dbh_attributes;
         }
 
-        my $rv = $response->rv;
+        my $rv = $response->rv; # may be undef on error
         if ($response->sth_resultsets) {
             # setup first resultset - including sth attributes
             $sth->more_results;
         }
         else {
             $sth->STORE(Active => 0);
-            $sth->{go_rows} = $response->rv;
+            $sth->{go_rows} = $rv;
         }
         # set error/warn/info (after more_results as that'll clear err)
         DBD::Gofer::set_err_from_response($sth, $response);
 
-        return $response->rv;
+        return $rv;
     }
 
 
@@ -827,10 +838,12 @@ The C<...> represents attributes that influence the operation of the Gofer
 driver or transport. These are described below or in the documentation of the
 transport module being used.
 
+=encoding ISO8859-1
+
 =head1 DESCRIPTION
 
 DBD::Gofer is a DBI database driver that forwards requests to another DBI
-driver, usually in a seperate process, often on a separate machine. It tries to
+driver, usually in a separate process, often on a separate machine. It tries to
 be as transparent as possible so it appears that you are using the remote
 driver directly.
 
@@ -910,7 +923,7 @@ They can be set after connect() but the change is only applied locally.
 
 =head2 You can't change statement handle attributes after prepare()
 
-You can't change statment handle attributes after prepare.
+You can't change statement handle attributes after prepare.
 
 An exception is made for attributes with names starting "C<private_>":
 They can be set after prepare() but the change is only applied locally.
@@ -953,7 +966,7 @@ implemented the private_attribute_info() method (added in DBI 1.54).
 
 Driver-private sth attributes can be set in the prepare() call. TODO
 
-Some driver-private dbh attributes may not be available if the driver has not
+Some driver-private sth attributes may not be available if the driver has not
 implemented the private_attribute_info() method (added in DBI 1.54).
 
 =head2 Multiple Resultsets
@@ -1056,7 +1069,7 @@ driver.
 
 The stream driver also launches a subprocess and writes requests and reads
 responses, like the pipeone transport.  In this case, however, the subprocess
-is expected to handle more that one request. (Though it will be automitically
+is expected to handle more that one request. (Though it will be automatically
 restarted if it exits.)
 
 This is the first transport that is truly useful because it can launch the
@@ -1178,7 +1191,7 @@ $request->is_idempotent is true (i.e., the dbh has the ReadOnly attribute set
 or the SQL statement is obviously a SELECT without a FOR UPDATE clause.)
 
 For even more control you can use the C<go_cache> attribute to pass in an
-instanciated cache object. Individual methods, including prepare(), can also
+instantiated cache object. Individual methods, including prepare(), can also
 specify alternative caches via the C<go_cache> attribute. For example, to
 specify no caching for a particular query, you could use
 
@@ -1186,6 +1199,12 @@ specify no caching for a particular query, you could use
 
 This can be used to implement different caching policies for different statements.
 
+It's interesting to note that DBD::Gofer can be used to add client-side caching
+to any (gofer compatible) application, with no code changes and no need for a
+gofer server.  Just set the DBI_AUTOPROXY environment variable like this:
+
+    DBI_AUTOPROXY='dbi:Gofer:transport=null;cache=1'
+
 =head1 CONFIGURING BEHAVIOUR POLICY
 
 DBD::Gofer supports a 'policy' mechanism that allows you to fine-tune the number of round-trips to the Gofer server.
@@ -1236,7 +1255,7 @@ L<DBI>
 
 This section aims to record issues to be aware of when using Gofer with specific drivers.
 It usually only documents issues that are not natural consequences of the limitations
-of the Gofer approach - as documented avove.
+of the Gofer approach - as documented above.
 
 =head1 TODO
 
@@ -1259,7 +1278,7 @@ in such a way that appropriate http cache headers are added to the results
 so that web caches (squid etc) could be used to implement the caching.
 (MUST require the use of GET rather than POST requests.)
 
-Rework handling of installed_methods to not piggback on dbh_attributes?
+Rework handling of installed_methods to not piggyback on dbh_attributes?
 
 Perhaps support transactions for transports where it's possible (ie null and stream)?
 Would make stream transport (ie ssh) more useful to more people.
