@@ -5,9 +5,9 @@
     require Carp;
 
     @EXPORT = qw(); # Do NOT @EXPORT anything.
-    $VERSION = sprintf("12.%06d", q$Revision: 14572 $ =~ /(\d+)/o);
+    $VERSION = sprintf("12.%06d", q$Revision: 14895 $ =~ /(\d+)/o);
 
-#   $Id: NullP.pm 14572 2010-12-14 21:34:51Z REHSACK $
+#   $Id: NullP.pm 14895 2011-07-05 06:47:42Z REHSACK $
 #
 #   Copyright (c) 1994-2007 Tim Bunce
 #
@@ -118,6 +118,7 @@
             $sth->{dbd_nullp_data} = [ @{$params}{ sort keys %$params } ];
             $sth->STORE(Active => 1); 
         }
+        # force a sleep - handy for testing
         elsif ($sth->{Statement} =~ m/^ \s* SLEEP \s+ (\S+) /xmsi) {
             my $secs = $1;
             if (eval { require Time::HiRes; defined &Time::HiRes::sleep }) {
@@ -127,6 +128,11 @@
                 sleep $secs;
             }
         }
+        # force an error - handy for testing
+        elsif ($sth->{Statement} =~ m/^ \s* ERROR \s+ (\d+) \s* (.*) /xmsi) {
+            return $sth->set_err($1, $2);
+        }
+        # anything else is silently ignored, sucessfully
 	1;
     }
 
