@@ -26,7 +26,7 @@ require 5.004;
 use strict;
 
 use RPC::PlServer 0.2001;
-# require DBI; # deferred till AcceptVersion() to aid threading
+require DBI;
 require Config;
 
 
@@ -651,7 +651,7 @@ Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
 		},
 
 		# rule: employee_workplace
-		# desc: get detailled informations
+		# desc: get detailled information
 		{
 			# any IP-address is meant here
 			mask => '^10\.95\.81\.(\d+)$',
